indexing

	description: "A single MIME parameter as it occurs in a MIME header field."

	author: "Berend de Boer"
	date: "$Date: 2006/06/01 $"
	revision: "$Revision: #1 $"

class

	EPX_MIME_PARAMETER


creation

	make


feature {NONE} -- Initialization

	make (a_name, a_value: STRING) is
		require
			valid_name: is_valid_parameter_name (a_name.as_lower)
			valid_value: a_value /= Void
		do
			name := a_name
			name.to_lower
			value := a_value
		end


feature -- Output

	append_to_string (s: STRING) is
			-- Stream contents of MIME structure to a STRING.
		require
			s_not_void: s /= Void
		do
			s.append_string (once_semicolon_space)
			s.append_string (name)
			s.append_character ('=')
			s.append_character ('%"')
			s.append_string (value)
			s.append_character ('%"')
		end


feature -- Access

	name: STRING
			-- Name of MIME field. Name is lowercase only, makes looking
			-- for names much easier.

	value: STRING
			-- Parameter value.


feature -- Status

	is_valid_parameter_name (a_name: STRING): BOOLEAN is
			-- Is `a_name' valid parameter name?
			-- It cannot be empty, must be lowercase and contain only
			-- valid characters.
		do
			-- @@BdB: must check for valid characters here...
			Result :=
				a_name /= Void and then
				not a_name.is_empty and then
				a_name.as_lower.is_equal (a_name)
		end


feature {NONE} -- Once strings

	once_semicolon_space: STRING is "; "


invariant

	valid_name: is_valid_parameter_name (name)
	valid_value: value /= Void and then not value.has ('%"')

end
